@@ -27,11 +27,6 @@
 #ifndef KBBGRAPHICSITEMBALLREPOSITORY_H
 #define KBBGRAPHICSITEMBALLREPOSITORY_H
 
-
-
-#include <KRandomSequence>
-
-
 #include "kbbgraphicsitem.h"
 class KBBGraphicsItemSet;
 class KBBScalableGraphicWidget;
@@ -63,8 +58,6 @@ class KBBGraphicsItemBallRepository : public KBBGraphicsItem
 		KBBScalableGraphicWidget* m_parent;
 		KBBThemeManager* m_themeManager;
 
-		KRandomSequence m_random;
-
 		int m_columns;
 		int m_rows;
 		int m_width;
