@@ -34,7 +34,6 @@
 #include <QAction>
 #include <QFont>
 #include <QGraphicsScene>
-#include <QGraphicsView>
 #include <QLCDNumber>
 #include <QResizeEvent>
 
@@ -285,7 +284,7 @@ void KBBScalableGraphicWidget::newGame(int columns, int rows, int ballNumber)
 		m_cursor->setBoardSize(m_columns, m_rows);
 		m_scene->setSceneRect(m_ballRepository->x() - RATIO, 0, m_columns*RATIO + 2*BORDER_SIZE - m_ballRepository->x() + RATIO, m_rows*RATIO + 2*BORDER_SIZE);
 	}
-	resizeEvent(0);
+	resizeEvent(nullptr);
 	setInputAccepted(true);
 }
 
