@@ -35,7 +35,7 @@
 #include <KAboutData>
 #include <QApplication>
 #include <QCommandLineParser>
-#include <kdelibs4configmigrator.h>
+#include <Kdelibs4ConfigMigrator>
 #include <KCrash>
 
 #include "kbbmainwindow.h"
@@ -45,6 +45,9 @@
 
 int main( int argc, char **argv )
 {
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+    
     QApplication application(argc, argv);
 
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kblackbox"));
